class Algorithm:
    """
    算法类， 导入的算法必须定义class Algorithm， 并放入 algorithm.py 文件中
    """

    def __init__(self, parameters):
        """
        初始化， parameters 为 dict格式的参数信息， 比如
        {
            "params1": "value1",
            "params1", 2
        }
        """
        self.parameters = parameters
        self.framework_log = self.parameters.get('framework_log')   # 日志
        pass

    def load(self, path):
        """
        加载模型
            不需要调用，只需要在这里实现加载模型的方法，并赋值给一个属性就可以，例如：
            self.model = xxxx.load(path)
            上线流程：算法框架会将模型文件放在model/下，然后进行函数的执行
            本地流程：可以通过model.yaml中location字段进行配置，然后会传入path参数
            Args:
                path : 模型文件路径，根据 model.yaml 文件中的 location 字段指定
            Returns:
                无
        """
        pass
    
    def save(self, path):
        """
        保存模型， 保存为 path 的文件或文件夹会被框架程序自动打包上传到服务器
        如果是path是文件夹，需要加上/， 系统会创建该文件夹
            Args:
                path : 模型文件路径， 文件名或文件夹名，根据算法自定义
            Returns:
                无
        """
        pass

    def train(self, train_data, val_data, **kwargs):
        """
        模型训练
            Args:
                train_data : 训练数据
                val_data : 验证数据
                [{
                    "meta": [   // 表头
                        {"code": "column_a"},
                        {"code": "column_b"}
                    ],
                    "result": [ // 表体
                        ["line_1_column_1", "line_1_column_2"],
                        ["line_2_column_1", "line_2_column_2"]
                    ]
                },...]

                kwargs: 特征工程后返回的数据
                {
                    "final_target_col": 3,     // 目标列下标
                    "category_cols": [1,2,3]   // 类别列下标
                }
            Returns:
                无
        """
        pass

    def infer(self, test_data):
        """
        推理
            Args:
                test_data : 推理请求数据, json格式， data参数必须存在
                {
                    "id"： xxx # 用户定义唯一id，透传回给用户请求
                    "data": 任意格式，注意二进制可能需要base64编码 # 推理数据
                }
            Returns:
                推理结果, json
                {
                    "id": xxx # 用户定义唯一id，跟请求对应
                    "data"： 结果数据，任意格式，注意二进制可能需要base64编码 # 推理数据
                }
        """
        pass

    def report_train_info(self, loss, lr, iter, batchsize=1):
        """
        上报训练信息
            Args:
                loss： 损失函数loss值
                lr： 学习率
                iter： 当前iteration
                batchsize： 每批次数据量大小
            Returns:
                无
        """
        pass

    def report_val_info(self, **kwargs):
        """
        上报验证信息
            Args:
                无
            Returns:
                无
        """
        pass

    def report_stat_info(self, **kwargs):
        """
        上报数据统计
            Args:
                无
            Returns:
                无
        """
        pass


