#!/usr/bin/env python
# coding: utf-8

import logging
import requests
import json
import time
import os


class Singleton(type):
    _instances = {}

    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
        return cls._instances[cls]


class Logger(metaclass=Singleton):
    def __init__(self):
        FORMAT = '%(asctime)s-%(levelname)s-%(filename)s[%(lineno)d]: %(message)s'
        logging.basicConfig(level=logging.INFO, format=FORMAT)
        self.logger = logging.getLogger(__name__)
        rq = time.strftime('%Y%m%d%H', time.localtime(time.time()))
        log_path = '/root/logs/'
        if os.access(log_path, os.W_OK):
            log_name = log_path + rq + '.log'
            fh = logging.FileHandler(log_name)
            formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
            fh.setLevel(logging.DEBUG)  # 输出到file的log等级的开关
            fh.setFormatter(formatter)
            self.logger.addHandler(fh)

    def get_logger(self):
        return self.logger


logger = None


def get_logger():
    global logger
    if logger is None:
        logger = Logger().get_logger()
    return logger
